<?php

namespace Drupal\tailwind_merge_classes\Twig;

use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;
use TailwindMerge\TailwindMerge;

class TailwindMergeClassesTwigExtension extends AbstractExtension {

    /**
     * Registers custom Twig functions.
     *
     * @return \Twig\TwigFunction[]
     *   An array of custom Twig functions.
     */
    public function getFunctions() {
        return [
            new TwigFunction('tw_merge', [$this, 'mergeTailwindClasses']),
            new TwigFunction('tw_merge_as_array', [$this, 'mergeTailwindClassesAsArray']),
        ];
    }

    /**
     * Merges Tailwind CSS classes into a string.
     *
     * @param string ...$classes
     *   Tailwind classes to merge.
     *
     * @return string
     *   Merged classes as string.
     */
    public function mergeTailwindClasses(...$classes): string {
        return TailwindMerge::instance()->merge(...$classes);
    }

    /**
     * Merges Tailwind CSS classes and returns them as an array.
     *
     * @param string ...$classes
     *   Tailwind classes to merge.
     *
     * @return array
     *   Merged classes as array.
     */
    public function mergeTailwindClassesAsArray(...$classes): array {
        $merged = TailwindMerge::instance()->merge(...$classes);
        return explode(' ', $merged);
    }

}
